@@ -3,7 +3,7 @@
 #-# 
 #-# xsnow: let it snow on your desktop
 #-# Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
-#-# 	      2019,2020,2021,2022 Willem Vermin
+#-# 	      2019,2020,2021,2022,2023 Willem Vermin
 #-# 
 #-# This program is free software: you can redistribute it and/or modify
 #-# it under the terms of the GNU General Public License as published by
@@ -83,6 +83,12 @@ fi
 
 FLAGS="$FLAGS -DVERSION=\"$version\""
 
+FLAGS="$FLAGS -DLANGUAGES=\"\""
+
+FLAGS="$FLAGS -I.."
+
+echo "#define HAVE_GSL_INTERP_CSPLINE 1" > config.h
+
 cd src || exit 1
 echo "removing .o files:"
 rm -f *.o
