@@ -2,7 +2,7 @@
 #-# 
 #-# xsnow: let it snow on your desktop
 #-# Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
-#-# 	      2019,2020,2021,2022 Willem Vermin
+#-# 	      2019,2020,2021,2022,2023 Willem Vermin
 #-# 
 #-# This program is free software: you can redistribute it and/or modify
 #-# it under the terms of the GNU General Public License as published by
@@ -28,6 +28,7 @@
 #include <sys/stat.h>
 #include <gsl/gsl_sort.h>
 #include <math.h>
+#include "mygettext.h"
 #include "xsnow.h"
 #include "utils.h"
 #include "windows.h"
@@ -36,7 +37,7 @@
 #include "version.h"
 #include "flags.h"
 #include "safe_malloc.h"
-
+#include "xdo.h"
 
 void traceback()
 #ifdef TRACEBACK_AVAILALBLE
@@ -241,10 +242,10 @@ void rgba2color(GdkRGBA *c, char **s)
 void Thanks(void)
 {
    if (global.HaltedByInterrupt)
-      printf("\nXsnow: Caught signal %d\n",global.HaltedByInterrupt);
+      printf(_("\nXsnow: Caught signal %d\n"),global.HaltedByInterrupt);
    if (strlen(global.Message))
       printf("\n%s\n",global.Message);
-   printf("\nThank you for using xsnow\n");
+   printf(_("\nThanks for using xsnow\n"));
    fflush(stdout);
 }
 
@@ -347,4 +348,73 @@ float gaussf(float x, float mu, float sigma)
    float y2 = y*y;
    return expf(-y2);
 }
+// guess language. return string like "en", "nl" or NULL if no language can
+// be found
+char *guess_language()
+{
+   const char *tries[] = {"LANGUAGE","LANG","LC_ALL","LC_MESSAGES","LC_NAME","LC_TIME",NULL};
+   char *a, *b;
+   int i = 0;
+   while (tries[i])
+   {
+      a = getenv(tries[i]);
+      if (a && strlen(a)>0)
+      {
+	 b = strdup(a);
+	 char *p = strchr(b,'_');
+	 if (p)
+	 {
+	    *p = 0;
+	    return b;
+	 }
+	 else
+	 {
+	    return b;
+	 }
+	 free(b);
+      }
+      ++i;
+   }
+   return NULL;
+}
+
+// find largest window with name
+Window  largest_window_with_name(xdo_t *myxdo, const char *name)
+{
+   xdo_search_t search;
+
+   memset(&search,0,sizeof(xdo_search_t));
+
+   search.searchmask     = SEARCH_NAME;
+   search.winname        = name;
+   search.require        = SEARCH_ANY;
+   search.max_depth      = 4;
+   search.limit          = 0;
+
+   Window *windows = NULL;
+   unsigned int nwindows;
+
+   xdo_search_windows(myxdo, &search, &windows, &nwindows);
+   P("nwindows: %s %d\n",search.winname,nwindows);
+   unsigned int i;
+   Window w = 0;
+   unsigned int maxsize = 0;
+
+   for (i=0; i<nwindows; i++)
+   {
+      unsigned int width,height;
+      xdo_get_window_size(myxdo, windows[i], &width, &height);
+      P("window: 0x%lx %d %d\n",windows[i],width,height);
+      unsigned int size = width*height;
+      if (size <= maxsize)
+         continue;
+      P("width %d height %d size %d prev maxsize %d\n",width,height, size, maxsize);
+      maxsize = size;
+      w = windows[i];
+   }
+   if (windows)
+      free(windows);
+   return w;
+}
+
 
