@@ -2,7 +2,7 @@
 #-# 
 #-# xsnow: let it snow on your desktop
 #-# Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
-#-# 	      2019,2020,2021,2022 Willem Vermin
+#-# 	      2019,2020,2021,2022,2023 Willem Vermin
 #-# 
 #-# This program is free software: you can redistribute it and/or modify
 #-# it under the terms of the GNU General Public License as published by
@@ -27,15 +27,11 @@ extern void         windows_ui(void);
 extern void         windows_draw(void);
 extern void         windows_init(void);
 extern int          WorkspaceActive(void);
-extern int          DetermineWindow(Window *xtrans, char **xtransname, GtkWidget **gtrans,const char *transname, int *IsDesktop);
 extern void         InitDisplayDimensions();
-extern void         DestroyWindow(Window w);
 extern void         setabove(GtkWindow *w);
 extern void         DisplayDimensions(void);
 extern Window       XWinInfo(char **name);
 extern void         UpdateFallenSnowRegions(void);
 extern void         UpdateFallenSnowRegionsWithLock(void);
-extern void         UpdateWindows(void);
 extern void         SetBackground(void);
 extern int          xinerama(Display *display, int xscreen, int *x, int *y, int *w, int *h);
-extern int          IsVisibleWindow(Window wid);
