@@ -2,7 +2,7 @@
 #-# 
 #-# xsnow: let it snow on your desktop
 #-# Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
-#-# 	      2019,2020,2021,2022 Willem Vermin
+#-# 	      2019,2020,2021,2022,2023 Willem Vermin
 #-# 
 #-# This program is free software: you can redistribute it and/or modify
 #-# it under the terms of the GNU General Public License as published by
@@ -25,9 +25,6 @@
 
 extern long int     GetCurrentWorkspace();
 extern int          GetWindows(WinInfo **w, int *nw);
-extern Window       FindWindowWithName(Display *dsp, const char* needle);
 extern WinInfo     *FindWindow(WinInfo *windows, int nwin, Window id);
 extern void         printwindows(Display *dpy,WinInfo *windows, int nwin);
-extern int          GetProperty32(Display *display, Window window, const char *atomname, 
-      const char *needle, int *props, const int nprops);
 
